Method: Shortcut::HistoryReferenceGroup#initialize
- Defined in:
- lib/shortcut_client_ruby/models/history_reference_group.rb
#initialize(attributes = {}) ⇒ HistoryReferenceGroup
Initializes the object
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/shortcut_client_ruby/models/history_reference_group.rb', line 52 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Shortcut::HistoryReferenceGroup` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Shortcut::HistoryReferenceGroup`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'entity_type') self.entity_type = attributes[:'entity_type'] end if attributes.key?(:'name') self.name = attributes[:'name'] end end |